@@ -106,9 +106,11 @@ class CLI(cl1.CLI):
 		elif self.argument_present('--generate'):
 			
 			# generate a key.
+			passphrase = self.get_argument("--passphrase").replace("\\", "").replace("\ ", "")
+			print("Passphrase:",passphrase)
 			response = key.generate(
 				directory=self.get_argument("--path"), 
-				passphrase=self.get_argument("--passphrase").replace("\\", ""), 
+				passphrase=passphrase, 
 				comment=self.get_argument("--comment"),)
 			r3sponse.log(response=response)
 
