@@ -428,10 +428,10 @@ class Key(object):
 		if comment == None: comment = ""
 		if "[#id:" not in comment: comment += f" [#id:{utils.__generate_shell_string__(characters=48, numerical_characters=True, special_characters=True)}]"
 		comment = '-C "{}"'.format(comment)
-		passphrase = '-N '+utils.__string_to_bash__(passphrase)
+		passphrase = '-N '+passphrase#utils.__string_to_bash__(passphrase)
 
 		# execute.
-		os.system(f'ssh-keygen -q -v -o -a 100 -t ed25519 {passphrase} {identity_file} {comment}')
+		os.system(f'ssh-keygen -q -v -o -a 100 -t ed25519 "{passphrase}" {identity_file} {comment}')
 		if not os.path.exists(private_key): 
 			utils.__delete_file_path__(directory, forced=True, sudo=True)
 			response["error"] = f"Failed to generate key [{directory}]."
